/**
  *  \file planetscentral/format/packer.cc
  *  \brief Format: Packer base class
  */

#include <stdexcept>
#include "planetscentral/format/packer.h"
#include "io/io.h"

Packer::Packer()
    : is_utf8(false),
      charset()
{ }

Packer::~Packer()
{ }

void
Packer::setCharset(string_t charset)
{
    if (CharacterSet::isCharsetNameUtf8(charset)) {
        this->is_utf8 = true;
    } else {
        CharacterSet n = CharacterSet::getCharsetByName(charset);
        if (!n.isValid()) {
            throw std::runtime_error("Invalid charset");
        }
        this->is_utf8 = false;
        this->charset = n;
    }
}

void
Packer::packString(char* out, std::size_t size, string_t str) const
{
    if (is_utf8) {
        storeBasicStringN(out, size, str);
    } else {
        storeBasicStringN(out, size, charset.convertFromUtf8(str));
    }
}

string_t
Packer::packString(const string_t& in) const
{
    if (is_utf8) {
        return in;
    } else {
        return charset.convertFromUtf8(in);
    }
}

string_t
Packer::unpackString(const char* in, std::size_t size) const
{
    return is_utf8
        ? getBasicStringN(in, size)
        : charset.convertToUtf8(getBasicStringN(in, size));
}

string_t
Packer::unpackString(const string_t& in) const
{
    if (is_utf8) {
        return in;
    } else {
        return charset.convertToUtf8(in);
    }
}
