#!/usr/bin/perl -w
#
#  Database Initialisation
#
#  Use as
#    C2CONFIG=path/to/c2config.txt perl -Ipath/to/c2web dbinit.pl [init|update]
#
#  (the environment variable and "-I" is to present this script a
#  similar execution environment than the CGI scripts.)
#

use strict;
use c2db;

# Since this can be dangerous, check execution environment.
if (!exists $ENV{C2CONFIG}
    || exists $ENV{GATEWAY_INTERFACE}
    || exists $ENV{REQUEST_METHOD}
    || @ARGV != 1
    || ($ARGV[0] ne 'init' && $ARGV[0] ne 'update'))
  {
      print STDERR "Invalid invocation. Use as\n";
      print STDERR "    C2CONFIG=path/to/c2config.txt perl -Ipath/to/c2web $0 [init|update]\n";
      exit 1;
  }

my $init = ($ARGV[0] eq 'init');


#
#  Load some files
#

my $fizz     = file("fizz.bin");
my $tim_rst  = file("d/tim/player11.rst");
my $tim_fizz = file("d/tim/fizz.bin");

#
#  Connect to servers
#

my $result = c2db::openDB();
if (ref($result)) {
    die "Unable to connect to database: $result->[0]\n";
}
$result = c2db::openFS();
if (ref($result)) {
    die "Unable to connect to file server: $result->[0]\n";
}
$result = c2db::openHFS();
if (ref($result)) {
    die "Unable to connect to host file server: $result->[0]\n";
}

#
#  Initialize database
#

c2db::callDB("flushall")                  if $init;
c2db::callDB("set", "user:uid", 1000)     if $init;

# Block some user names
foreach (qw(root admin sysop moderator)) {
    c2db::callDB("setnx", "uid:$_", 0);
}

# Default profile
c2db::callDB("hmset", "default:profile",
             "limitfiles" => 1000,
             "limitkbytes" => 20000,
             "allowupload" => 1,
             "allowadmin" => 0);
c2db::callDB("hmset", "default:profilecopy",
             "termsversion" => 1);


#
#  Initialize files
#

c2db::callFS("RMDIR", "u")                if $init;
c2db::callFS("RMDIR", "r")                if $init;
c2db::callFS("RMDIR", "d")                if $init;

# User data directory (initially empty)
c2db::callFS("MKDIR", "u");

# Server reg keys
c2db::callFS("MKDIR", "r");
c2db::callFS("MKDIR", "r/unreg");
c2db::callFS("PUT", "r/unreg/fizz.bin", $fizz);
c2db::callFS("SETPERM", "r/unreg", "*", "r");
c2db::callFS("SETPERM", "r", "*", "r");

# Demo games
c2db::callFS("MKDIR", "d");
c2db::callFS("SETPERM", "d", "*", "r");

c2db::callFS("MKDIR", "d/tim");
c2db::callFS("SETPERM", "d/tim", "*", "r");
c2db::callFS("PROPSET", "d/tim", "name", "Tim's demo RST");
c2db::callFS("PUT", "d/tim/player11.rst", $tim_rst);
c2db::callFS("PUT", "d/tim/fizz.bin", $tim_fizz);


#
#  Host
#
c2db::callHFS("MKDIR", "bin");
c2db::callHFS("MKDIR", "games");
c2db::callHFS("MKDIR", "tools");
c2db::callHFS("PUT", "bin/runhost.sh", file("runhost.sh"));
c2db::callHFS("PUT", "bin/checkturn.sh", file("checkturn.sh"));


#
#  Finish
#

c2db::closeDB();
c2db::closeFS();
c2db::closeHFS();
exit 0;


# Function to return a file's content as string
sub file {
    my $name = shift;
    open FILE, "< $name" or die "$name: $!";
    binmode FILE;
    my $content = join "", <FILE>;
    close FILE;
    $content;
}
