/**
  *  \file planetscentral/net/md5.h
  *  \brief Networking: MD5
  *
  *  Copyright (C) 1991-2, RSA Data Security, Inc. Created 1991. All
  *  rights reserved.
  *
  *  License to copy and use this software is granted provided that it
  *  is identified as the "RSA Data Security, Inc. MD5 Message-Digest
  *  Algorithm" in all material mentioning or referencing this software
  *  or this function.
  *
  *  License is also granted to make and use derivative works provided
  *  that such works are identified as "derived from the RSA Data
  *  Security, Inc. MD5 Message-Digest Algorithm" in all material
  *  mentioning or referencing the derived work.
  *
  *  RSA Data Security, Inc. makes no representations concerning either
  *  the merchantability of this software or the suitability of this
  *  software for any particular purpose. It is provided "as is"
  *  without express or implied warranty of any kind.
  *
  *  These notices must be retained in any copies of any part of this
  *  documentation and/or software.
  */
#ifndef C2SERVER_PLANETSCENTRAL_NET_MD5_H
#define C2SERVER_PLANETSCENTRAL_NET_MD5_H

/** MD5 Message Digest Calculator. This is the RSA reference code
    from the RFC nicely wrapped in a C++ class. */
#include "cpluslib/types.h"

class Md5Context {
    uint32_t state[4];                                   /* state (ABCD) */
    uint32_t count[2];        /* number of bits, modulo 2^64 (lsb first) */
    unsigned char buffer[64];                                 /* input buffer */

 public:

    void init();

    void update(const unsigned char*, unsigned int);

    void final(unsigned char [16]);

    static void hmac(const unsigned char* text, unsigned int text_len,
                     const unsigned char* key, unsigned int key_len,
                     unsigned char digest[16]);
};

#endif
